Module ability

Module ability 

Module to manage abilities.

Structs

ActivateAbility
Event to make an actor activate an ability.
ActivateAbilityTrigger
Trigger to build and fire an ActivateAbility event.

Type Aliases

AbilitiesAlteration
Encapsulatess the data used to describe an alteration of one or more abilities.
AbilitiesSeed
Type to drive the generation of a given actor’s set of abilities.
Ability
Type to represent an ability.
AbilityId
Alias for Ability<R>::Id.
Activation
Type to customize in which way an ability is activated.