Module actor

Module actor 

Entities that can activate abilities.

Structs

Action
An action is comprised by an actor who activates an ability with a given activation profile.
AlterAbilities
An event to alter the abilities of an actor.
AlterAbilitiesTrigger
Trigger to build and fire an AlterAbilities event.
RegenerateAbilities
An event to regenerate the abilities of an actor.
RegenerateAbilitiesTrigger
Trigger to build and fire a RegenerateAbilities event.

Traits

Actor
A trait for objects which possess abilities and can act during a turn.
ActorRules
Set of rules that handle how abilities are represented and how they can alter the state of the world when activated.