RegenerateAbilities

Struct RegenerateAbilities 

pub struct RegenerateAbilities<R: BattleRules> { /* private fields */ }
An event to regenerate the abilities of an actor.

A new set of abilities is created from a seed.\

  • Abilities already known by the actor won’t be modified.
  • Abilities that the actor didn’t have before will be added.
  • Current actor’s abilities that are not present in the new set will be removed from the actor.

Examples

use weasel::{
    battle_rules, rules::empty::*, Battle, BattleController, BattleRules, CreateCreature,
    CreateTeam, EntityId, EventKind, EventTrigger, RegenerateAbilities, Server,
};

battle_rules! {}

let battle = Battle::builder(CustomRules::new()).build();
let mut server = Server::builder(battle).build();

let team_id = 1;
CreateTeam::trigger(&mut server, team_id).fire().unwrap();
let creature_id = 1;
let position = ();
CreateCreature::trigger(&mut server, creature_id, team_id, position)
    .fire()
    .unwrap();

RegenerateAbilities::trigger(&mut server, EntityId::Creature(creature_id))
    .fire()
    .unwrap();
assert_eq!(
    server.battle().history().events().iter().last().unwrap().kind(),
    EventKind::RegenerateAbilities
);

Implementations

Source

impl<R: BattleRules> RegenerateAbilities<R>

pub fn trigger<P: EventProcessor<R>>( processor: &mut P, id: EntityId<R>, ) -> RegenerateAbilitiesTrigger<'_, R, P>

Returns a trigger for this event.

pub fn id(&self) -> &EntityId<R>

Returns the actor’s entity id.

pub fn seed(&self) -> &Option<AbilitiesSeed<R>>

Returns the seed to regenerate the actor’s abilities.