Module entity

Module entity 

Module for entities and their storage.

Structs

Entities
Data structure to manage ownership of teams and entities.
RemoveEntity
Helper to get an event trigger capable of removing an entity from the battle.
It delegates the actual work to a RemoveCreature or a RemoveObject.
RemoveEntityTrigger
Trigger to build and a fire the correct event to remove an entity.

Enums

EntityId
Id to uniquely identify an entity. EntityId is used as global id to identify entities in the game world regardless of their type.
Transmutation
Represents a change to an entity’s existence.

Traits

Entity
An entity represents any being existing in the game world.