Module player

Module player 

Player-oriented features.

Structs

RightsHandle
A structure to access player’s rights. Rights are used to control which players can act on behalf of what teams.
RightsHandleMut
A structure to access and manipulate player’s rights. Rights are used to control which players can act on behalf of what teams.

Type Aliases

PlayerId
Type to uniquely identify players.