Collection of generic rules.
Modules
- ability
- Generic implementations for all purpose abilities.
- empty
- This module contains implementations for components that do nothing. Such rules are useful if you don’t need to implement any logic for a particular module.
- entropy
- Predefined rules for entropy.
- statistic
- Generic implementations for different types of statistic.
- status
- Generic implementations for all purpose statuses.