Module to manage abilities.
Structs
- Activate
Ability - Event to make an actor activate an ability.
- Activate
Ability Trigger - Trigger to build and fire an
ActivateAbilityevent.
Type Aliases
- Abilities
Alteration - Encapsulatess the data used to describe an alteration of one or more abilities.
- Abilities
Seed - Type to drive the generation of a given actor’s set of abilities.
- Ability
- Type to represent an ability.
- Ability
Id - Alias for
Ability<R>::Id. - Activation
- Type to customize in which way an ability is activated.