Entities that can activate abilities.
Structs
- Action
- An action is comprised by an actor who activates an ability with a given activation profile.
- Alter
Abilities - An event to alter the abilities of an actor.
- Alter
Abilities Trigger - Trigger to build and fire an
AlterAbilitiesevent. - Regenerate
Abilities - An event to regenerate the abilities of an actor.
- Regenerate
Abilities Trigger - Trigger to build and fire a
RegenerateAbilitiesevent.
Traits
- Actor
- A trait for objects which possess abilities and can act during a turn.
- Actor
Rules - Set of rules that handle how abilities are represented and how they can alter the state of the world when activated.