Module for entities and their storage.
Structs
- Entities
- Data structure to manage ownership of teams and entities.
- Remove
Entity - Helper to get an event trigger capable of removing an entity from the battle.
It delegates the actual work to aRemoveCreatureor aRemoveObject. - Remove
Entity Trigger - Trigger to build and a fire the correct event to remove an entity.
Enums
- Entity
Id - Id to uniquely identify an entity.
EntityIdis used as global id to identify entities in the game world regardless of their type. - Transmutation
- Represents a change to an entity’s existence.
Traits
- Entity
- An entity represents any being existing in the game world.