pub enum EventRights<'a, R: BattleRules> {
None,
Server,
Team(&'a TeamId<R>),
Teams(Vec<&'a TeamId<R>>),
}Expand description
Types of access rights that might be required in order to fire an event.
Variants
None
Everyone can fire the event.
Server
Only the server can fire the event.
Team(&'a TeamId<R>)
Only the server or a player with rights to this team can fire the event.
Teams(Vec<&'a TeamId<R>>)
Only the server or a player with rights to all of these teams can fire the event.